//@bstructure

#include <iostream>
#include <functional>
#include <cmath>
#include <vector>
#include <queue>
#include <thread>
#include <mutex>
#include <atomic>

#include <pthread.h>

using namespace std;

#define MAXTHREADS 4

typedef struct {
  mutex m;
  queue<int> q;
  function<void(int)> f;
} t_chunked_for_data;

void* chunked_for_thread(void *pdata) {
  auto data = (t_chunked_for_data*)pdata;
  while (true) {
    data->m.lock();
    if (data->q.empty()) {
      data->m.unlock();
      break;
    }
    int j = data->q.front();
    data->q.pop();
    data->m.unlock();
    data->f(j);
  }
  return NULL;
}

void chunked_for(int lo, int up, int chunk, const function<void(int)>& f) {
#ifndef _OPENMP
  t_chunked_for_data data;
  for (int i = lo; i <= up; i += chunk) {
    data.q.push(i);
  }

  data.f = f;

#ifndef __clang__
  vector<thread> threads;
#else
  vector<pthread_t> threads;
#endif

  for (int i = 0; i < MAXTHREADS; ++i) {
#ifdef __clang__
    pthread_t t;
    pthread_create(&t, NULL, chunked_for_thread, &data);
    threads.push_back(t);
#else
   threads.push_back(thread([&data,&f] () {
     while (true) {
       data.m.lock();
       if (data.q.empty()) {
         data.m.unlock();
         break;
      }
       int j = data.q.front();
       data.q.pop();
       data.m.unlock();
       f(j);
     }
   }));
#endif
  }

#ifdef __clang__
  for (auto thr : threads) {
    pthread_join(thr, NULL);
  }
#else
  for (auto& thr : threads) {
    thr.join();
  }
#endif
#else
#pragma omp parallel for default(none) shared(lo,up,chunk,f) schedule(dynamic)
  for (int i = lo; i <= up; i += chunk) {
    f(i);
  }
#endif
}

int main() {
  int N;
  cin >> N;

#ifdef OPENMP
  __int64_t sum = 0;
  int count = 0;
#else
  atomic<__int64_t> sum;
  atomic<int> count;
  sum = 0;
  count = 0;
#endif

  int lim = (int)sqrt((float)N);

  vector<bool> sieve(lim+1, false);
  vector<int> sieving_primes;
  sieving_primes.reserve(lim);
  for (int i = 2; i*i <= lim; ++i) {
    if (!sieve[i]) {
      for (int j = i*i; j <= lim; j += i) {
        sieve[j] = true;
      }
    }
  }
  for (int i = 2; i <= lim; ++i) {
    if (!sieve[i]) sieving_primes.push_back(i);
  }
  for (int p : sieving_primes) {
    count ++;
    sum += p;
  }

  const int chunk_size = 180000;
  chunked_for(lim + 1, N, chunk_size, [&] (int i) {
    int lo = i, up = min(i + chunk_size-1, N);
    int size = up - lo + 1;
    vector<bool> sieve(size, false);
    for (int p : sieving_primes) {
      int j = lo / p * p;
      if (j < lo) j += p;
      for ( ; j <= up; j += p) {
        sieve[j - lo] = true;
      }
    }
    for (int j = lo; j <= up; ++j) {
      if (!sieve[j-lo]) {
#pragma omp critical
        sum += j;
#pragma omp critical
        count ++;
      }
    }
  }
  );

  cout << sum << endl;

  return 0;
}

